# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='pyponto',
    version='1.0.0',
    url='https://github.com/hendrixcosta/pyponto',
    license='MIT License',
    author='Hendrix Costa',
    author_email='hendrixcosta@gmail.com',
    keywords='pyponto registro ponto funcionario',
    description=u'Registrar ponto de funcionários',
    packages=['pyponto'],
    install_requires=[],
)